#
# PySNMP MIB module Finisher-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/Finisher-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:48 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( hrDeviceIndex, ) = mibBuilder.importSymbols("HOST-RESOURCES-MIB", "hrDeviceIndex")
( PrtMarkerSuppliesSupplyUnitTC, PrtMediaUnitTC, prtMIBConformance, PrtInputTypeTC, PresentOnOff, printmib, PrtCapacityUnitTC, PrtMarkerSuppliesTypeTC, PrtMarkerSuppliesClassTC, PrtSubUnitStatusTC, ) = mibBuilder.importSymbols("Printer-MIB", "PrtMarkerSuppliesSupplyUnitTC", "PrtMediaUnitTC", "prtMIBConformance", "PrtInputTypeTC", "PresentOnOff", "printmib", "PrtCapacityUnitTC", "PrtMarkerSuppliesTypeTC", "PrtMarkerSuppliesClassTC", "PrtSubUnitStatusTC")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Bits, ModuleIdentity, Counter32, IpAddress, Unsigned32, MibIdentifier, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, mib_2, experimental, NotificationType, Counter64, TimeTicks, Gauge32, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "ModuleIdentity", "Counter32", "IpAddress", "Unsigned32", "MibIdentifier", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "mib-2", "experimental", "NotificationType", "Counter64", "TimeTicks", "Gauge32", "Integer32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
finisherMIB = ModuleIdentity((1, 3, 6, 1, 3, 64))
if mibBuilder.loadTexts: finisherMIB.setLastUpdated('9810090000Z')
if mibBuilder.loadTexts: finisherMIB.setOrganization('IETF Printer MIB Working Group')
if mibBuilder.loadTexts: finisherMIB.setContactInfo("Ron Bergman\n         Dataproducts Corp.\n         1757 Tapo Canyon Road\n         Simi Valley, CA 91063-3394\n         rbergma@dpc.com\n\n        Send comments to the printmib WG using the Finisher MIB\n        Project (FIN) Mailing List:  fin@pwg.org\n\n        For further information, access the PWG web page under 'FIN':\n              http://www.pwg.org/\n\n        Implementers of this specification are encouraged to join the\n        fin mailing list in order to participate in discussions on any\n        clarifications needed and registration proposals being reviewed\n        in order to achieve consensus.")
if mibBuilder.loadTexts: finisherMIB.setDescription('The MIB module for management of printer finisher units.\n         The Finisher MIB is an extension of the Printer MIB.')
class FinDeviceTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("stitcher", 3), ("folder", 4), ("binder", 5), ("trimmer", 6), ("dieCutter", 7), ("puncher", 8), ("perforater", 9), ("slitter", 10), ("separationCutter", 11), ("imprinter", 12), ("wrapper", 13), ("bander", 14), ("makeEnvelope", 15), ("stacker", 16), ("sheetRotator", 17),)

class FinAttributeTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 30, 31, 40, 50, 80, 81, 82, 83, 100, 130, 160, 161, 162,))
    namedValues = NamedValues(("other", 1), ("deviceName", 3), ("deviceVendorName", 4), ("deviceModel", 5), ("deviceVersion", 6), ("deviceSerialNumber", 7), ("maximumSheets", 8), ("finProcessOffsetUnits", 9), ("finReferenceEdge", 10), ("finAxisOffset", 11), ("finJogEdge", 12), ("finHeadLocation", 13), ("finOperationRestrictions", 14), ("finNumberOfPositions", 15), ("namedConfiguration", 16), ("finMediaTypeRestriction", 17), ("finPrinterInputTraySupported", 18), ("finPreviousFinishingOperation", 19), ("finNextFinishingOperation", 20), ("stitchingType", 30), ("stitchingDirection", 31), ("foldingType", 40), ("bindingType", 50), ("punchHoleType", 80), ("punchHoleSizeLongDim", 81), ("punchHoleSizeShortDim", 82), ("punchPattern", 83), ("slittingType", 100), ("wrappingType", 130), ("stackOutputType", 160), ("stackOffset", 161), ("stackRotation", 162),)

class FinEdgeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(3, 4, 5, 6,))
    namedValues = NamedValues(("topEdge", 3), ("bottomEdge", 4), ("leftEdge", 5), ("rightEdge", 6),)

class FinStitchingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5, 6, 7, 8, 9, 10,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("stapleTopLeft", 4), ("stapleBottomLeft", 5), ("stapleTopRight", 6), ("stapleBottomRight", 7), ("saddleStitch", 8), ("edgeStitch", 9), ("stapleDual", 10),)

class StitchingDirTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(2, 3, 4,))
    namedValues = NamedValues(("unknown", 2), ("topDown", 3), ("bottomUp", 4),)

class StitchingAngleTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(2, 3, 4, 5,))
    namedValues = NamedValues(("unknown", 2), ("horizontal", 3), ("vertical", 4), ("slanted", 5),)

class FinFoldingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("zFold", 3), ("halfFold", 4), ("letterFold", 5),)

class FinBindingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5, 6, 7, 8, 9, 10, 11,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("tape", 4), ("plastic", 5), ("velo", 6), ("perfect", 7), ("spiral", 8), ("adhesive", 9), ("comb", 10), ("padding", 11),)

class FinPunchHoleTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("round", 3), ("oblong", 4), ("square", 5), ("rectangular", 6), ("star", 7),)

class FinPunchPatternTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("twoHoleUSTop", 4), ("threeHoleUS", 5), ("twoHoleDIN", 6), ("fourHoleDIN", 7), ("twentyTwoHoleUS", 8), ("nineteenHoleUS", 9), ("twoHoleMetric", 10), ("swedish4Hole", 11), ("twoHoleUSSide", 12), ("fiveHoleUS", 13), ("sevenHoleUS", 14), ("mixed7H4S", 15), ("norweg6Hole", 16), ("metric26Hole", 17), ("metric30Hole", 18),)

class FinSlittingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("slitAndSeparate", 4), ("slitAndMerge", 5),)

class FinWrappingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("shrinkWrap", 4), ("paperWrap", 5),)

class FinStackOutputTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5, 6,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("straight", 4), ("offset", 5), ("crissCross", 6),)

finDevice = MibIdentifier((1, 3, 6, 1, 2, 1, 43, 30))
finDeviceTable = MibTable((1, 3, 6, 1, 2, 1, 43, 30, 1), )
if mibBuilder.loadTexts: finDeviceTable.setDescription('This table defines the finishing device subunits,\n       including information regarding possible configuration\n       options and the status for each finisher device subunit.')
finDeviceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 43, 30, 1, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"), (0, "Finisher-MIB", "finDeviceIndex"))
if mibBuilder.loadTexts: finDeviceEntry.setDescription('There is an entry in the finishing device table for each\n       possible finisher process.')
finDeviceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: finDeviceIndex.setDescription('A unique value used to identify a finisher process.\n       Although these values may change due to a major\n       reconfiguration of the printer system (e.g. the addition\n       of new finishing processes), the values are normally\n       expected to remain stable across successive power cycles.')
finDeviceType = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 2), FinDeviceTypeTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceType.setDescription('Defines the type of finishing process associated with this\n       table row entry.')
finDevicePresentOnOff = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 3), PresentOnOff().clone('notPresent')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finDevicePresentOnOff.setDescription('Indicates if this finishing device subunit is available\n       and whether the device subunit is enabled.')
finDeviceCapacityUnit = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 4), PrtCapacityUnitTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceCapacityUnit.setDescription('The unit of measure for specifying the capacity of this\n       finisher device subunit.')
finDeviceMaxCapacity = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647)).clone(-2)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finDeviceMaxCapacity.setDescription('The maximum capacity of this finisher device subunit in\n       finDeviceCapacityUnits.  If the device can reliably sense\n       this value, the value is sensed by the finisher device\n       and is read-only: otherwise the value may be written by a\n       management or control console application.  The value (-1)\n       means other and specifically indicates that the device\n       places no restrictions on this parameter.  The value (-2)\n       means unknown.')
finDeviceCurrentCapacity = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647)).clone(-2)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finDeviceCurrentCapacity.setDescription('The current capacity of this finisher device subunit in\n       finDeviceCapacityUnits.  If the device can reliably sense\n       this value, the value is sensed by the finisher and is\n       read-only: otherwise the value may be written by a\n       management or control console application.  The value (-1)\n       means other and specifically indicates that the device\n       places no restrictions on this parameter.  The value (-2)\n       means unknown.')
finDeviceAssociatedMediaPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 7), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceAssociatedMediaPaths.setDescription('Indicates the media paths which can supply media for this\n       finisher device.  The value of this object is a bit map in an\n       octet string with each position representing the value of a\n       prtMediaPathIndex.  For a media path that can be a source\n       for this finisher device subunit, the bit position equal\n       to one less than the value of prtMediaPathIndex will be set.\n       The bits are numbered starting with the most significant bit of\n       the first byte being bit 0, the least significant bit of the\n       first byte being bit 7, the most significant of the second byte\n       being bit 8, and so on.')
finDeviceAssociatedOutputs = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 8), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceAssociatedOutputs.setDescription('Indicates the printer output subunits this finisher device\n       subunit services.  The value of this object is a bit map in an\n       octet string with each position representing the value of a\n       prtOutputIndex.  For an output subunit that is serviced\n       by this finisher device subunit, the bit position equal to\n       to one less than the value of prtOutputIndex will be set.\n       The bits are numbered starting with the most significant bit of\n       the first byte being bit 0, the least significant bit of the\n       first byte being bit 7, the most significant of the second byte\n       being bit 8, and so on.')
finDeviceStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 9), PrtSubUnitStatusTC().clone(5)).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceStatus.setDescription('Indicates the current status of this finisher device\n       subunit.')
finDeviceDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 30, 1, 1, 10), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finDeviceDescription.setDescription('A free form text description of this device subunit in the\n       localization specified by prtGeneralCurrentLocalization.')
finSupply = MibIdentifier((1, 3, 6, 1, 2, 1, 43, 31))
finSupplyTable = MibTable((1, 3, 6, 1, 2, 1, 43, 31, 1), )
if mibBuilder.loadTexts: finSupplyTable.setDescription('Each unique source of supply is an entry in the finisher\n       supply table. Each supply entry has its own\n       characteristics associated with it such as colorant and\n       current supply level.')
finSupplyEntry = MibTableRow((1, 3, 6, 1, 2, 1, 43, 31, 1, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"), (0, "Finisher-MIB", "finSupplyIndex"))
if mibBuilder.loadTexts: finSupplyEntry.setDescription('A list of finisher devices, with their associated\n       supplies and supplies characteristics.')
finSupplyIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: finSupplyIndex.setDescription('A unique value used by a finisher to identify this supply\n       container/receptacle.  Although these values may change\n       due to a major reconfiguration of the finisher (e.g. the\n       addition of new supply sources to the finisher), values\n       are normally expected to remain stable across successive\n       power cycles.')
finSupplyDeviceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyDeviceIndex.setDescription('The value of finDeviceIndex corresponding to the finishing\n       device subunit with which this finisher supply is associated.')
finSupplyClass = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 3), PrtMarkerSuppliesClassTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyClass.setDescription('This value indicates whether this supply entity\n       represents a supply that is consumed or a container that\n       is filled.')
finSupplyType = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 4), PrtMarkerSuppliesTypeTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyType.setDescription('The type of this supply.')
finSupplyDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyDescription.setDescription('The description of this supply/receptacle in text useful\n       for operators and management applications and in the\n       localization specified by prtGeneralCurrentLocalization.')
finSupplyUnit = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 6), PrtMarkerSuppliesSupplyUnitTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyUnit.setDescription('Unit of measure of this finisher supply container or\n       receptacle.')
finSupplyMaxCapacity = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647)).clone(-2)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMaxCapacity.setDescription('The maximum capacity of this supply container/receptacle\n       expressed in Supply Units.  If this supply container/\n       receptacle can reliably sense this value, the value is\n       sensed  and is read-only; otherwise the value may be\n       written by a control panel or management application.  The\n       value (-1) means other and places no restrictions on this\n       parameter.  The value (-2) means unknown.')
finSupplyCurrentLevel = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 8), Integer32().clone(-2)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyCurrentLevel.setDescription('The current level if this supply is a container; the\n       remaining space if this supply is a receptacle. If this\n       supply container/receptacle can reliably sense this value,\n       the value is sensed  and is read-only; otherwise the value\n       may be written by a control panel or management\n       application.  The value (-1) means other and places no\n       restrictions on this parameter. The value (-2) means\n       unknown.  A value of (-3) means that the printer knows there\n       is some supply or remaining space.')
finSupplyColorName = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 31, 1, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,63))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyColorName.setDescription('The name of the color of this colorant using standardized\n       string names from ISO 10175 (DPA) and ISO 10180 (SPDL)\n       which are: other, unknown, white, red, green, blue, cyan,\n       magenta, yellow and black.  Implementors may add\n       additional string values.  The naming conventions in ISO\n       9070 are recommended in order to avoid potential name\n       clashes.')
finSupplyMediaInput = MibIdentifier((1, 3, 6, 1, 2, 1, 43, 32))
finSupplyMediaInputTable = MibTable((1, 3, 6, 1, 2, 1, 43, 32, 1), )
if mibBuilder.loadTexts: finSupplyMediaInputTable.setDescription('The input subunits associated with a finisher supply media\n       are each represented by an entry in this table.')
finSupplyMediaInputEntry = MibTableRow((1, 3, 6, 1, 2, 1, 43, 32, 1, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"), (0, "Finisher-MIB", "finSupplyMediaInputIndex"))
if mibBuilder.loadTexts: finSupplyMediaInputEntry.setDescription('A list of finisher supply media input subunit features and\n       characteristics.')
finSupplyMediaInputIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: finSupplyMediaInputIndex.setDescription('A unique value used by a finisher to identify this supply\n       media input subunit.  Although these values may change\n       due to a major reconfiguration of the finisher (e.g. the\n       addition of new supply media input sources to the\n       finisher), values are normally expected to remain stable\n       across successive power cycles.')
finSupplyMediaInputDeviceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputDeviceIndex.setDescription('The value of finDeviceIndex corresponding to the finishing\n       device subunit with which this finisher media supply is\n       associated.')
finSupplyMediaInputSupplyIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputSupplyIndex.setDescription('The value of finSupplyIndex corresponding to the finishing\n       supply subunit with which this finisher media supply is\n       associated.')
finSupplyMediaInputType = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 4), PrtInputTypeTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputType.setDescription('The type of technology (discriminated primarily according\n       to the feeder mechanism type) employed by the input\n       subunit.')
finSupplyMediaInputDimUnit = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 5), PrtMediaUnitTC()).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputDimUnit.setDescription('The unit of measure for specifying dimensional values for\n       this input device.')
finSupplyMediaInputMediaDimFeedDir = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaDimFeedDir.setDescription('This object provides the value of the dimension in the\n       feed direction of the media that is placed or will be\n       placed in this input device.  Feed dimension measurements\n       are taken parallel to the feed direction of the device and\n       measured in finSupplyMediaInputDimUnits.  If this input\n       device can reliably sense this value, the value is sensed\n       and is read-only access. Otherwise the value is read-write\n       access and may be written by management or control panel\n       applications. The value (-1) means other and specifically\n       indicates that this device places no restrictions on this\n       parameter. The value (-2) indicates unknown. ')
finSupplyMediaInputMediaDimXFeedDir = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaDimXFeedDir.setDescription('This object provides the value of the dimension across the\n       feed direction of the media that is placed or will be\n       placed in this input device.  The cross feed direction is\n       ninety degrees relative to the feed direction on this\n       device and measured in finSupplyMediaInputDimUnits.  If\n       this input device can reliably sense this value, the value\n       is sensed and is read-only access. Otherwise the value is\n       read-write access and may be written by management or\n       control panel applications. The value (-1) means other and\n       specifically indicates that this device places no\n       restrictions on this parameter. The value (-2) indicates\n       unknown. ')
finSupplyMediaInputStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 8), PrtSubUnitStatusTC().clone(5)).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputStatus.setDescription('This value indicates the current status of this input\n       device.')
finSupplyMediaInputMediaName = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,63))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaName.setDescription('The name of the current media contained in this input\n       device. Examples are Engineering Manual Cover, Section A Tab\n       Divider or any ISO standard names.')
finSupplyMediaInputName = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 10), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,63))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputName.setDescription('The name assigned to this input subunit.')
finSupplyMediaInputDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 11), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: finSupplyMediaInputDescription.setDescription('A free form text description of this input subunit in the\n       localization specified by prtGeneralCurrentLocalization.')
finSupplyMediaInputSecurity = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 12), PresentOnOff()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputSecurity.setDescription('Indicates if this subunit has some security associated\n       with it.')
finSupplyMediaInputMediaWeight = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 13), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaWeight.setDescription('The weight of the media associated with this Input device\n       in grams per meter squared.  The value (-1) means other\n       and specifically indicates that the device places no\n       restriction on this parameter.  The value (-2) means\n       unknown.  This object can be used to calculate the weight\n       of individual pages processed by the document finisher.\n       This value, when multiplied by the number of pages in a\n       finished set, can be used to calculate the weight of a set\n       before it is inserted into a mailing envelope.')
finSupplyMediaInputMediaThickness = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaThickness.setDescription('This object identifies the thickness of the input media\n       processed by this document input subunit measured in\n       micrometers.  This value may be used by devices (or\n       operators) to set up proper machine tolerances for the\n       feeder operation.  The value (-2) indicates that the media\n       thickness is unknown or not used in the setup for this\n       input subunit.')
finSupplyMediaInputMediaType = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 32, 1, 1, 15), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,63))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finSupplyMediaInputMediaType.setDescription('The name of the type of medium associated with this input\n       subunit.  Valid values are standardized strings from ISO 10175\n       (DPA) and ISO 10180 (SPDL) which are: stationary, transparency,\n       envelope, envelope-plain, envelope window, continuous-long,\n       continuous-short, tab-stock, labels, multi-layer.')
finDeviceAttribute = MibIdentifier((1, 3, 6, 1, 2, 1, 43, 33))
finDeviceAttributeTable = MibTable((1, 3, 6, 1, 2, 1, 43, 33, 1), )
if mibBuilder.loadTexts: finDeviceAttributeTable.setDescription('The attribute table defines special parameters that are\n       applicable only to a minority of the finisher devices.\n       An attribute table entry is used, rather than unique\n       objects, to minimize the number of MIB objects and to\n       allow for expansion without the addition of MIB objects.\n       Each finisher device is represented by a separate row\n       in the device subunit attribute table.')
finDeviceAttributeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 43, 33, 1, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"), (0, "Finisher-MIB", "finDeviceIndex"), (0, "Finisher-MIB", "finDeviceAttributeTypeIndex"), (0, "Finisher-MIB", "finDeviceAttributeInstanceIndex"))
if mibBuilder.loadTexts: finDeviceAttributeEntry.setDescription('Each entry defines a finisher function parameter that\n       cannot be represented by an object in the finisher\n       device subunit table.')
finDeviceAttributeTypeIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 33, 1, 1, 1), FinAttributeTypeTC())
if mibBuilder.loadTexts: finDeviceAttributeTypeIndex.setDescription('Defines the attribute type represented by this row.')
finDeviceAttributeInstanceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 33, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: finDeviceAttributeInstanceIndex.setDescription('An index that allows the discrimination of an attribute\n       instance when the same attribute occurs multiple times for\n       a specific instance of a finisher function.  The value of\n       this index shall be 1 if only a single instance of the\n       attribute occurs for the specific finisher function.')
finDeviceAttributeValueAsInteger = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 33, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2,2147483647)).clone(-2)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finDeviceAttributeValueAsInteger.setDescription("Defines the integer value of the attribute.  The value of\n       the attribute is represented as an integer if the\n       finAttributeTypeTC description for the attribute has the\n       tag 'INTEGER:'.\n\n       Depending upon the attribute enum definition, this object\n       may be either an integer, a counter, an index, or an enum.\n       Attributes for which the concept of an integer value is\n       not meaningful SHALL return a value of -1 for this\n       attribute.")
finDeviceAttributeValueAsOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 43, 33, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,63)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: finDeviceAttributeValueAsOctets.setDescription("Contains the octet string value of the attribute.  The\n       value of the attribute is represented as a string if the\n       finAttributeTypeTC description for the attribute has the\n       tag 'OCTETS:'.\n\n       Depending upon the attribute enum definition, this object\n       may be either a coded character set string (text) or a\n       binary octet string.  Attributes for which the concept of\n       an octet string value is not meaningful SHALL contain a\n       zero length string.")
finMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 43, 2, 3)).setObjects(*(("Finisher-MIB", "finDeviceGroup"), ("Finisher-MIB", "finSupplyGroup"), ("Finisher-MIB", "finDeviceAttributeGroup"),))
if mibBuilder.loadTexts: finMIBCompliance.setDescription('The compliance statement for agents that implement the\n        finisher MIB.')
finMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 43, 2, 4))
finDeviceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 43, 2, 4, 1)).setObjects(*(("Finisher-MIB", "finDeviceType"), ("Finisher-MIB", "finDevicePresentOnOff"), ("Finisher-MIB", "finDeviceCapacityUnit"), ("Finisher-MIB", "finDeviceMaxCapacity"), ("Finisher-MIB", "finDeviceCurrentCapacity"), ("Finisher-MIB", "finDeviceAssociatedMediaPaths"), ("Finisher-MIB", "finDeviceAssociatedOutputs"), ("Finisher-MIB", "finDeviceStatus"), ("Finisher-MIB", "finDeviceDescription"),))
if mibBuilder.loadTexts: finDeviceGroup.setDescription('The finisher device group.')
finSupplyGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 43, 2, 4, 2)).setObjects(*(("Finisher-MIB", "finSupplyDeviceIndex"), ("Finisher-MIB", "finSupplyClass"), ("Finisher-MIB", "finSupplyType"), ("Finisher-MIB", "finSupplyDescription"), ("Finisher-MIB", "finSupplyUnit"), ("Finisher-MIB", "finSupplyMaxCapacity"), ("Finisher-MIB", "finSupplyCurrentLevel"), ("Finisher-MIB", "finSupplyColorName"),))
if mibBuilder.loadTexts: finSupplyGroup.setDescription('The finisher supply group.')
finSupplyMediaInputGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 43, 2, 4, 3)).setObjects(*(("Finisher-MIB", "finSupplyMediaInputDeviceIndex"), ("Finisher-MIB", "finSupplyMediaInputSupplyIndex"), ("Finisher-MIB", "finSupplyMediaInputType"), ("Finisher-MIB", "finSupplyMediaInputDimUnit"), ("Finisher-MIB", "finSupplyMediaInputMediaDimFeedDir"), ("Finisher-MIB", "finSupplyMediaInputMediaDimXFeedDir"), ("Finisher-MIB", "finSupplyMediaInputStatus"), ("Finisher-MIB", "finSupplyMediaInputMediaName"), ("Finisher-MIB", "finSupplyMediaInputName"), ("Finisher-MIB", "finSupplyMediaInputDescription"), ("Finisher-MIB", "finSupplyMediaInputSecurity"), ("Finisher-MIB", "finSupplyMediaInputMediaWeight"), ("Finisher-MIB", "finSupplyMediaInputMediaThickness"), ("Finisher-MIB", "finSupplyMediaInputMediaType"),))
if mibBuilder.loadTexts: finSupplyMediaInputGroup.setDescription('The finisher supply, media input group.')
finDeviceAttributeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 43, 2, 4, 4)).setObjects(*(("Finisher-MIB", "finDeviceAttributeValueAsInteger"), ("Finisher-MIB", "finDeviceAttributeValueAsOctets"),))
if mibBuilder.loadTexts: finDeviceAttributeGroup.setDescription('The finisher device attribute group.')
mibBuilder.exportSymbols("Finisher-MIB", finDeviceMaxCapacity=finDeviceMaxCapacity, finSupplyTable=finSupplyTable, finSupplyMediaInputIndex=finSupplyMediaInputIndex, finSupplyMediaInputMediaName=finSupplyMediaInputMediaName, finDevice=finDevice, finSupplyIndex=finSupplyIndex, finSupplyDescription=finSupplyDescription, FinStackOutputTypeTC=FinStackOutputTypeTC, FinBindingTypeTC=FinBindingTypeTC, finisherMIB=finisherMIB, finSupplyMediaInputDimUnit=finSupplyMediaInputDimUnit, finSupplyMediaInputSecurity=finSupplyMediaInputSecurity, finSupplyMaxCapacity=finSupplyMaxCapacity, finDeviceEntry=finDeviceEntry, FinEdgeTC=FinEdgeTC, FinFoldingTypeTC=FinFoldingTypeTC, finDeviceIndex=finDeviceIndex, FinAttributeTypeTC=FinAttributeTypeTC, finDeviceAttributeEntry=finDeviceAttributeEntry, finDeviceAttributeValueAsOctets=finDeviceAttributeValueAsOctets, finSupplyMediaInputMediaType=finSupplyMediaInputMediaType, FinPunchHoleTypeTC=FinPunchHoleTypeTC, finMIBCompliance=finMIBCompliance, finDeviceAttributeInstanceIndex=finDeviceAttributeInstanceIndex, FinPunchPatternTC=FinPunchPatternTC, FinStitchingTypeTC=FinStitchingTypeTC, finSupplyMediaInputDescription=finSupplyMediaInputDescription, finSupplyUnit=finSupplyUnit, finSupplyMediaInputName=finSupplyMediaInputName, finDeviceTable=finDeviceTable, finSupplyMediaInputEntry=finSupplyMediaInputEntry, finSupplyMediaInputMediaWeight=finSupplyMediaInputMediaWeight, StitchingDirTypeTC=StitchingDirTypeTC, finSupplyMediaInputSupplyIndex=finSupplyMediaInputSupplyIndex, finSupplyEntry=finSupplyEntry, FinDeviceTypeTC=FinDeviceTypeTC, finSupplyCurrentLevel=finSupplyCurrentLevel, finDeviceDescription=finDeviceDescription, finDeviceStatus=finDeviceStatus, finSupplyType=finSupplyType, finSupplyMediaInputTable=finSupplyMediaInputTable, finSupplyMediaInputMediaDimXFeedDir=finSupplyMediaInputMediaDimXFeedDir, finDeviceCurrentCapacity=finDeviceCurrentCapacity, PYSNMP_MODULE_ID=finisherMIB, StitchingAngleTypeTC=StitchingAngleTypeTC, finSupplyDeviceIndex=finSupplyDeviceIndex, finDeviceAssociatedOutputs=finDeviceAssociatedOutputs, finSupplyClass=finSupplyClass, finDeviceAttributeValueAsInteger=finDeviceAttributeValueAsInteger, finMIBGroups=finMIBGroups, finSupplyMediaInputGroup=finSupplyMediaInputGroup, finDevicePresentOnOff=finDevicePresentOnOff, finSupply=finSupply, finDeviceCapacityUnit=finDeviceCapacityUnit, finDeviceGroup=finDeviceGroup, finSupplyGroup=finSupplyGroup, finDeviceAttributeTypeIndex=finDeviceAttributeTypeIndex, finDeviceAttributeGroup=finDeviceAttributeGroup, finSupplyMediaInputMediaDimFeedDir=finSupplyMediaInputMediaDimFeedDir, FinWrappingTypeTC=FinWrappingTypeTC, finSupplyColorName=finSupplyColorName, finDeviceAttributeTable=finDeviceAttributeTable, finSupplyMediaInput=finSupplyMediaInput, finSupplyMediaInputMediaThickness=finSupplyMediaInputMediaThickness, finSupplyMediaInputStatus=finSupplyMediaInputStatus, finSupplyMediaInputType=finSupplyMediaInputType, finDeviceType=finDeviceType, finSupplyMediaInputDeviceIndex=finSupplyMediaInputDeviceIndex, finDeviceAssociatedMediaPaths=finDeviceAssociatedMediaPaths, finDeviceAttribute=finDeviceAttribute, FinSlittingTypeTC=FinSlittingTypeTC)



#
# PySNMP MIB module ENTITY-STATE-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ENTITY-STATE-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:52 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Counter32, TimeTicks, Bits, mib_2, ObjectIdentity, IpAddress, ModuleIdentity, Integer32, Counter64, NotificationType, Gauge32, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Counter32", "TimeTicks", "Bits", "mib-2", "ObjectIdentity", "IpAddress", "ModuleIdentity", "Integer32", "Counter64", "NotificationType", "Gauge32", "MibIdentifier")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
entityStateTc = ModuleIdentity((1, 3, 6, 1, 2, 1, 130)).setRevisions(("2005-11-22 00:00",))
if mibBuilder.loadTexts: entityStateTc.setLastUpdated('200511220000Z')
if mibBuilder.loadTexts: entityStateTc.setOrganization('IETF Entity MIB Working Group')
if mibBuilder.loadTexts: entityStateTc.setContactInfo('General Discussion: entmib@ietf.org\n                 To Subscribe:\n                 http://www.ietf.org/mailman/listinfo/entmib\n\n                 http://www.ietf.org/html.charters/entmib-charter.html\n\n                 Sharon Chisholm\n                 Nortel Networks\n                 PO Box 3511 Station C\n                 Ottawa, Ont.  K1Y 4H7\n                 Canada\n                 schishol@nortel.com\n\n                 David T. Perkins\n                 548 Qualbrook Ct\n                 San Jose, CA 95110\n                 USA\n                 Phone: 408 394-8702\n                 dperkins@snmpinfo.com')
if mibBuilder.loadTexts: entityStateTc.setDescription('This MIB defines state textual conventions.\n\n                 Copyright (C) The Internet Society 2005.  This version\n                 of this MIB module is part of RFC 4268;  see the RFC\n                 itself for full legal notices.')
class EntityAdminState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("unknown", 1), ("locked", 2), ("shuttingDown", 3), ("unlocked", 4),)

class EntityOperState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("unknown", 1), ("disabled", 2), ("enabled", 3), ("testing", 4),)

class EntityUsageState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("unknown", 1), ("idle", 2), ("active", 3), ("busy", 4),)

class EntityAlarmStatus(Bits, TextualConvention):
    namedValues = NamedValues(("unknown", 0), ("underRepair", 1), ("critical", 2), ("major", 3), ("minor", 4), ("warning", 5), ("indeterminate", 6),)

class EntityStandbyStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("unknown", 1), ("hotStandby", 2), ("coldStandby", 3), ("providingService", 4),)

mibBuilder.exportSymbols("ENTITY-STATE-TC-MIB", EntityAdminState=EntityAdminState, EntityStandbyStatus=EntityStandbyStatus, PYSNMP_MODULE_ID=entityStateTc, EntityUsageState=EntityUsageState, entityStateTc=entityStateTc, EntityAlarmStatus=EntityAlarmStatus, EntityOperState=EntityOperState)



#
# PySNMP MIB module MPLS-L3VPN-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-L3VPN-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:20:45 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint")
( IANAipRouteProtocol, ) = mibBuilder.importSymbols("IANA-RTPROTO-MIB", "IANAipRouteProtocol")
( InterfaceIndex, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "InterfaceIndexOrZero")
( InetAddress, InetAutonomousSystemNumber, InetAddressPrefixLength, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAutonomousSystemNumber", "InetAddressPrefixLength", "InetAddressType")
( MplsIndexType, ) = mibBuilder.importSymbols("MPLS-LSR-STD-MIB", "MplsIndexType")
( mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( iso, Counter64, IpAddress, Integer32, NotificationType, Bits, ObjectIdentity, Unsigned32, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, MibIdentifier, TimeTicks, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "Counter64", "IpAddress", "Integer32", "NotificationType", "Bits", "ObjectIdentity", "Unsigned32", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "MibIdentifier", "TimeTicks", "Counter32")
( TextualConvention, DisplayString, RowStatus, TimeStamp, TruthValue, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "RowStatus", "TimeStamp", "TruthValue", "StorageType")
( VPNIdOrZero, ) = mibBuilder.importSymbols("VPN-TC-STD-MIB", "VPNIdOrZero")
mplsL3VpnMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 11)).setRevisions(("2006-01-23 00:00",))
if mibBuilder.loadTexts: mplsL3VpnMIB.setLastUpdated('200601230000Z')
if mibBuilder.loadTexts: mplsL3VpnMIB.setOrganization('IETF Layer-3 Virtual Private\n                 Networks Working Group.')
if mibBuilder.loadTexts: mplsL3VpnMIB.setContactInfo('        Thomas D. Nadeau\n                   tnadeau@cisco.com\n\n                   Harmen van der Linde\n                   havander@cisco.com\n\n                   Comments and discussion to l3vpn@ietf.org')
if mibBuilder.loadTexts: mplsL3VpnMIB.setDescription('This MIB contains managed object definitions for the\n         Layer-3 Multiprotocol Label Switching Virtual\n         Private Networks.\n\n        Copyright (C) The Internet Society (2006).  This\n        version of this MIB module is part of RFC4382; see\n        the RFC itself for full legal notices.')
class MplsL3VpnName(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,31)

class MplsL3VpnRouteDistinguisher(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,256)

class MplsL3VpnRtType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("import", 1), ("export", 2), ("both", 3),)

mplsL3VpnNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 0))
mplsL3VpnObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 1))
mplsL3VpnScalars = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1))
mplsL3VpnConf = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2))
mplsL3VpnPerf = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3))
mplsL3VpnRoute = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4))
mplsL3VpnConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 2))
mplsL3VpnConfiguredVrfs = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 1), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnConfiguredVrfs.setDescription('The number of VRFs that are configured on this node.')
mplsL3VpnActiveVrfs = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnActiveVrfs.setDescription('The number of VRFs that are active on this node.\n        That is, those VRFs whose corresponding mplsL3VpnVrfOperStatus\n        object value is equal to operational (1).')
mplsL3VpnConnectedInterfaces = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnConnectedInterfaces.setDescription('Total number of interfaces connected to a VRF.')
mplsL3VpnNotificationEnable = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 4), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mplsL3VpnNotificationEnable.setDescription("If this object is true, then it enables the\n         generation of all notifications defined in\n         this MIB.  This object's value should be\n         preserved across agent reboots.")
mplsL3VpnVrfConfMaxPossRts = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfConfMaxPossRts.setDescription('Denotes maximum number of routes that the device\n      will allow all VRFs jointly to hold.  If this value is\n      set to 0, this indicates that the device is\n      unable to determine the absolute maximum.  In this\n      case, the configured maximum MAY not actually\n      be allowed by the device.')
mplsL3VpnVrfConfRteMxThrshTime = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 6), Unsigned32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfConfRteMxThrshTime.setDescription('Denotes the interval in seconds, at which the route max threshold\n      notification may be reissued after the maximum value has been\n      exceeded (or has been reached if mplsL3VpnVrfConfMaxRoutes and\n      mplsL3VpnVrfConfHighRteThresh are equal) and the initial\n      notification has been issued.  This value is intended to prevent\n      continuous generation of notifications by an agent in the event\n      that routes are continually added to a VRF after it has reached\n      its maximum value.  If this value is set to 0, the agent should\n      only issue a single notification at the time that the maximum\n      threshold has been reached, and should not issue any more\n      notifications until the value of routes has fallen below the\n      configured threshold value.  This is the recommended default\n      behavior.')
mplsL3VpnIllLblRcvThrsh = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 1, 7), Unsigned32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mplsL3VpnIllLblRcvThrsh.setDescription("The number of illegally received labels above which\n        the mplsNumVrfSecIllglLblThrshExcd notification\n        is issued.  The persistence of this value mimics\n        that of the device's configuration.")
mplsL3VpnIfConfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1), )
if mibBuilder.loadTexts: mplsL3VpnIfConfTable.setDescription('This table specifies per-interface MPLS capability\n        and associated information.')
mplsL3VpnIfConfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1), ).setIndexNames((0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfName"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnIfConfIndex"))
if mibBuilder.loadTexts: mplsL3VpnIfConfEntry.setDescription('An entry in this table is created by an LSR for\n        every interface capable of supporting MPLS L3VPN.\n        Each entry in this table is meant to correspond to\n        an entry in the Interfaces Table.')
mplsL3VpnIfConfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: mplsL3VpnIfConfIndex.setDescription('This is a unique index for an entry in the\n        mplsL3VpnIfConfTable.  A non-zero index for an\n        entry indicates the ifIndex for the corresponding\n        interface entry in the MPLS-VPN-layer in the ifTable.\n        Note that this table does not necessarily correspond\n        one-to-one with all entries in the Interface MIB\n        having an ifType of MPLS-layer; rather, only those\n        that are enabled for MPLS L3VPN functionality.')
mplsL3VpnIfVpnClassification = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("carrierOfCarrier", 1), ("enterprise", 2), ("interProvider", 3),)).clone('enterprise')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnIfVpnClassification.setDescription("Denotes whether this link participates in a\n        carrier's carrier, enterprise, or inter-provider\n        scenario.")
mplsL3VpnIfVpnRouteDistProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1, 3), Bits().clone(namedValues=NamedValues(("none", 0), ("bgp", 1), ("ospf", 2), ("rip", 3), ("isis", 4), ("static", 5), ("other", 6),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnIfVpnRouteDistProtocol.setDescription('Denotes the route distribution protocol across the\n        PE-CE link.  Note that more than one routing protocol\n        may be enabled at the same time; thus, this object is\n        specified as a bitmask.  For example, static(5) and\n        ospf(2) are a typical configuration.')
mplsL3VpnIfConfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1, 4), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnIfConfStorageType.setDescription("The storage type for this VPN If entry.\n        Conceptual rows having the value 'permanent'\n        need not allow write access to any columnar\n        objects in the row.")
mplsL3VpnIfConfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnIfConfRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  Rows in this\n        table signify that the specified interface is\n        associated with this VRF.  If the row creation\n        operation succeeds, the interface will have been\n        associated with the specified VRF, otherwise the\n        agent MUST not allow the association.  If the agent\n        only allows read-only operations on this table, it\n        MUST create entries in this table as they are created\n        on the device.  When a row in this table is in\n        active(1) state, no objects in that row can be\n        modified except mplsL3VpnIfConfStorageType and\n        mplsL3VpnIfConfRowStatus.')
mplsL3VpnVrfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2), )
if mibBuilder.loadTexts: mplsL3VpnVrfTable.setDescription('This table specifies per-interface MPLS L3VPN\n        VRF Table capability and associated information.\n        Entries in this table define VRF routing instances\n        associated with MPLS/VPN interfaces.  Note that\n        multiple interfaces can belong to the same VRF\n        instance.  The collection of all VRF instances\n        comprises an actual VPN.')
mplsL3VpnVrfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1), ).setIndexNames((0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfName"))
if mibBuilder.loadTexts: mplsL3VpnVrfEntry.setDescription('An entry in this table is created by an LSR for\n        every VRF capable of supporting MPLS L3VPN.  The\n        indexing provides an ordering of VRFs per-VPN\n        interface.')
mplsL3VpnVrfName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 1), MplsL3VpnName())
if mibBuilder.loadTexts: mplsL3VpnVrfName.setDescription('The human-readable name of this VPN.  This MAY\n        be equivalent to the [RFC2685] VPN-ID, but may\n        also vary.  If it is set to the VPN ID, it MUST\n        be equivalent to the value of mplsL3VpnVrfVpnId.\n        It is strongly recommended that all sites supporting\n        VRFs that are part of the same VPN use the same\n        naming convention for VRFs as well as the same VPN\n        ID.')
mplsL3VpnVrfVpnId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 2), VPNIdOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfVpnId.setDescription('The VPN ID as specified in [RFC2685].  If a VPN ID\n        has not been specified for this VRF, then this\n        variable SHOULD be set to a zero-length OCTET\n        STRING.')
mplsL3VpnVrfDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 3), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfDescription.setDescription('The human-readable description of this VRF.')
mplsL3VpnVrfRD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 4), MplsL3VpnRouteDistinguisher()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRD.setDescription('The route distinguisher for this VRF.')
mplsL3VpnVrfCreationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfCreationTime.setDescription('The time at which this VRF entry was created.')
mplsL3VpnVrfOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfOperStatus.setDescription('Denotes whether or not a VRF is operational.  A VRF is\n        up(1) when there is at least one interface associated\n        with the VRF whose ifOperStatus is up(1).  A VRF is\n        down(2) when:\n        a. There does not exist at least one interface whose\n           ifOperStatus is up(1).\n        b. There are no interfaces associated with the VRF.')
mplsL3VpnVrfActiveInterfaces = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfActiveInterfaces.setDescription('Total number of interfaces connected to this VRF with\n        ifOperStatus = up(1).\n\n        This value should increase when an interface is associated\n        with the corresponding VRF and its corresponding ifOperStatus\n        is equal to up(1).  If an interface is associated whose\n        ifOperStatus is not up(1), then the value is not incremented\n        until such time as it transitions to this state.\n\n        This value should be decremented when an interface is\n        disassociated with a VRF or the corresponding ifOperStatus\n        transitions out of the up(1) state to any other state.\n       ')
mplsL3VpnVrfAssociatedInterfaces = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 8), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfAssociatedInterfaces.setDescription('Total number of interfaces connected to this VRF\n        (independent of ifOperStatus type).')
mplsL3VpnVrfConfMidRteThresh = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 9), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfMidRteThresh.setDescription('Denotes mid-level water marker for the number\n      of routes that this VRF may hold.')
mplsL3VpnVrfConfHighRteThresh = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 10), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfHighRteThresh.setDescription('Denotes high-level water marker for the number of\n      routes that this VRF may hold.')
mplsL3VpnVrfConfMaxRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 11), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfMaxRoutes.setDescription('Denotes maximum number of routes that this VRF is\n      configured to hold.  This value MUST be less than or\n      equal to mplsL3VpnVrfConfMaxPossRts unless it is set\n      to 0.')
mplsL3VpnVrfConfLastChanged = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 12), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfConfLastChanged.setDescription('The value of sysUpTime at the time of the last\n      change of this table entry, which includes changes of\n      VRF parameters defined in this table or addition or\n      deletion of interfaces associated with this VRF.')
mplsL3VpnVrfConfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 13), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.\n        When a row in this table is in active(1) state, no\n        objects in that row can be modified except\n        mplsL3VpnVrfConfAdminStatus, mplsL3VpnVrfConfRowStatus,\n        and mplsL3VpnVrfConfStorageType.')
mplsL3VpnVrfConfAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfAdminStatus.setDescription('Indicates the desired operational status of this\n         VRF.')
mplsL3VpnVrfConfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 2, 1, 15), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfConfStorageType.setDescription("The storage type for this VPN VRF entry.\n         Conceptual rows having the value 'permanent'\n         need not allow write access to any columnar\n         objects in the row.")
mplsL3VpnVrfRTTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3), )
if mibBuilder.loadTexts: mplsL3VpnVrfRTTable.setDescription('This table specifies per-VRF route target association.\n         Each entry identifies a connectivity policy supported\n         as part of a VPN.')
mplsL3VpnVrfRTEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1), ).setIndexNames((0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfName"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTIndex"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTType"))
if mibBuilder.loadTexts: mplsL3VpnVrfRTEntry.setDescription('An entry in this table is created by an LSR for\n        each route target configured for a VRF supporting\n        a MPLS L3VPN instance.  The indexing provides an\n        ordering per-VRF instance.  See [RFC4364] for a\n        complete definition of a route target.')
mplsL3VpnVrfRTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: mplsL3VpnVrfRTIndex.setDescription('Auxiliary index for route targets configured for a\n        particular VRF.')
mplsL3VpnVrfRTType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 3), MplsL3VpnRtType())
if mibBuilder.loadTexts: mplsL3VpnVrfRTType.setDescription('The route target distribution type.')
mplsL3VpnVrfRT = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 4), MplsL3VpnRouteDistinguisher()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRT.setDescription('The route target distribution policy.')
mplsL3VpnVrfRTDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 5), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRTDescr.setDescription('Description of the route target.')
mplsL3VpnVrfRTRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRTRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  When a row in this\n        table is in active(1) state, no objects in that row\n        can be modified except mplsL3VpnVrfRTRowStatus.')
mplsL3VpnVrfRTStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 3, 1, 7), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRTStorageType.setDescription("The storage type for this VPN route target (RT) entry.\n         Conceptual rows having the value 'permanent'\n         need not allow write access to any columnar\n         objects in the row.")
mplsL3VpnVrfSecTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 6), )
if mibBuilder.loadTexts: mplsL3VpnVrfSecTable.setDescription('This table specifies per MPLS L3VPN VRF Table\n        security-related counters.')
mplsL3VpnVrfSecEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 6, 1), )
mplsL3VpnVrfEntry.registerAugmentions(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfSecEntry"))
mplsL3VpnVrfSecEntry.setIndexNames(*mplsL3VpnVrfEntry.getIndexNames())
if mibBuilder.loadTexts: mplsL3VpnVrfSecEntry.setDescription('An entry in this table is created by an LSR for\n        every VRF capable of supporting MPLS L3VPN.  Each\n        entry in this table is used to indicate security-related\n        information for each VRF entry.')
mplsL3VpnVrfSecIllegalLblVltns = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 6, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfSecIllegalLblVltns.setDescription('Indicates the number of illegally received\n        labels on this VPN/VRF.\n\n        Discontinuities in the value of this counter can occur\n        at re-initialization of the management system, and at\n        other times as indicated by the value of\n        mplsL3VpnVrfSecDiscontinuityTime.')
mplsL3VpnVrfSecDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 2, 6, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfSecDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at\n        which any one or more of this entry's counters suffered\n        a discontinuity.  If no such discontinuities have\n        occurred since the last re-initialization of the local\n        management subsystem, then this object contains a zero\n        value.")
mplsL3VpnVrfPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1), )
if mibBuilder.loadTexts: mplsL3VpnVrfPerfTable.setDescription('This table specifies per MPLS L3VPN VRF Table performance\n        information.')
mplsL3VpnVrfPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1), )
mplsL3VpnVrfEntry.registerAugmentions(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfEntry"))
mplsL3VpnVrfPerfEntry.setIndexNames(*mplsL3VpnVrfEntry.getIndexNames())
if mibBuilder.loadTexts: mplsL3VpnVrfPerfEntry.setDescription('An entry in this table is created by an LSR for\n        every VRF capable of supporting MPLS L3VPN.')
mplsL3VpnVrfPerfRoutesAdded = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfPerfRoutesAdded.setDescription('Indicates the number of routes added to this VPN/VRF\n        since the last discontinuity.  Discontinuities in\n        the value of this counter can occur\n        at re-initialization of the management system, and at\n        other times as indicated by the value of\n        mplsL3VpnVrfPerfDiscTime.')
mplsL3VpnVrfPerfRoutesDeleted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfPerfRoutesDeleted.setDescription('Indicates the number of routes removed from this VPN/VRF.\n\n        Discontinuities in the value of this counter can occur\n        at re-initialization of the management system, and at\n        other times as indicated by the value of\n        mplsL3VpnVrfPerfDiscTime.')
mplsL3VpnVrfPerfCurrNumRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfPerfCurrNumRoutes.setDescription('Indicates the number of routes currently used by this\n        VRF.')
mplsL3VpnVrfPerfRoutesDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfPerfRoutesDropped.setDescription('This counter should be incremented when the number of routes\n        contained by the specified VRF exceeds or attempts to exceed\n        the maximum allowed value as indicated by\n        mplsL3VpnVrfMaxRouteThreshold.\n\n        Discontinuities in the value of this counter can occur\n        at re-initialization of the management system, and at\n        other times as indicated by the value of\n        mplsL3VpnVrfPerfDiscTime.')
mplsL3VpnVrfPerfDiscTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 3, 1, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfPerfDiscTime.setDescription("The value of sysUpTime on the most recent occasion at\n        which any one or more of this entry's counters suffered\n        a discontinuity.  If no such discontinuities have\n        occurred since the last re-initialization of the local\n        management subsystem, then this object contains a zero\n        value.")
mplsL3VpnVrfRteTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1), )
if mibBuilder.loadTexts: mplsL3VpnVrfRteTable.setDescription('This table specifies per-interface MPLS L3VPN VRF Table\n        routing information.  Entries in this table define VRF routing\n        entries associated with the specified MPLS/VPN interfaces.  Note\n        that this table contains both BGP and Interior Gateway Protocol\n        IGP routes, as both may appear in the same VRF.')
mplsL3VpnVrfRteEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1), ).setIndexNames((0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfName"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrDestType"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrDest"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrPfxLen"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrPolicy"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrNHopType"), (0, "MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrNextHop"))
if mibBuilder.loadTexts: mplsL3VpnVrfRteEntry.setDescription('An entry in this table is created by an LSR for every route\n        present configured (either dynamically or statically) within\n        the context of a specific VRF capable of supporting MPLS/BGP\n        VPN.  The indexing provides an ordering of VRFs per-VPN\n        interface.\n\n        Implementers need to be aware that there are quite a few\n        index objects that together can exceed the size allowed\n        for an Object Identifier (OID).  So implementers must make\n        sure that OIDs of column instances in this table will have\n        no more than 128 sub-identifiers, otherwise they cannot be\n        accessed using SNMPv1, SNMPv2c, or SNMPv3.')
mplsL3VpnVrfRteInetCidrDestType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 1), InetAddressType())
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrDestType.setDescription('The type of the mplsL3VpnVrfRteInetCidrDest address, as\n                defined in the InetAddress MIB.\n\n                Only those address types that may appear in an actual\n                routing table are allowed as values of this object.')
mplsL3VpnVrfRteInetCidrDest = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 2), InetAddress())
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrDest.setDescription('The destination IP address of this route.\n\n                The type of this address is determined by the value of\n                the mplsL3VpnVrfRteInetCidrDestType object.\n\n                The values for the index objects\n                mplsL3VpnVrfRteInetCidrDest and\n                mplsL3VpnVrfRteInetCidrPfxLen must be consistent.  When\n                the value of mplsL3VpnVrfRteInetCidrDest is x, then\n                the bitwise logical-AND of x with the value of the mask\n                formed from the corresponding index object\n                mplsL3VpnVrfRteInetCidrPfxLen MUST be\n                equal to x.  If not, then the index pair is not\n                consistent and an inconsistentName error must be\n                returned on SET or CREATE requests.')
mplsL3VpnVrfRteInetCidrPfxLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 3), InetAddressPrefixLength().subtype(subtypeSpec=ValueRangeConstraint(0,128)))
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrPfxLen.setDescription('Indicates the number of leading one bits that form the\n                mask to be logical-ANDed with the destination address\n                before being compared to the value in the\n                mplsL3VpnVrfRteInetCidrDest field.\n\n                The values for the index objects\n                mplsL3VpnVrfRteInetCidrDest and\n                mplsL3VpnVrfRteInetCidrPfxLen must be consistent.  When\n                the value of mplsL3VpnVrfRteInetCidrDest is x, then the\n                bitwise logical-AND of x with the value of the mask\n                formed from the corresponding index object\n                mplsL3VpnVrfRteInetCidrPfxLen MUST be\n                equal to x.  If not, then the index pair is not\n                consistent and an inconsistentName error must be\n                returned on SET or CREATE requests.')
mplsL3VpnVrfRteInetCidrPolicy = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 4), ObjectIdentifier())
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrPolicy.setDescription('This object is an opaque object without any defined\n                semantics.  Its purpose is to serve as an additional\n                index that may delineate between multiple entries to\n                the same destination.  The value { 0 0 } shall be used\n                as the default value for this object.')
mplsL3VpnVrfRteInetCidrNHopType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 5), InetAddressType())
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrNHopType.setDescription('The type of the mplsL3VpnVrfRteInetCidrNextHop address,\n                as defined in the InetAddress MIB.\n\n                Value should be set to unknown(0) for non-remote\n                routes.\n\n                Only those address types that may appear in an actual\n                routing table are allowed as values of this object.')
mplsL3VpnVrfRteInetCidrNextHop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 6), InetAddress())
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrNextHop.setDescription('On remote routes, the address of the next system en\n                route.  For non-remote routes, a zero-length string.\n                The type of this address is determined by the value of\n                the mplsL3VpnVrfRteInetCidrNHopType object.')
mplsL3VpnVrfRteInetCidrIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 7), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrIfIndex.setDescription('The ifIndex value that identifies the local interface\n                through which the next hop of this route should be\n                reached.  A value of 0 is valid and represents the\n                scenario where no interface is specified.')
mplsL3VpnVrfRteInetCidrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("reject", 2), ("local", 3), ("remote", 4), ("blackhole", 5),)).clone('other')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrType.setDescription('The type of route.  Note that local(3) refers to a\n                route for which the next hop is the final destination;\n                remote(4) refers to a route for which the next hop is\n                not the final destination.\n\n                Routes that do not result in traffic forwarding or\n                rejection should not be displayed even if the\n                implementation keeps them stored internally.\n\n                reject(2) refers to a route that, if matched, discards\n                the message as unreachable and returns a notification\n                (e.g., ICMP error) to the message sender.  This is used\n                in some protocols as a means of correctly aggregating\n                routes.\n\n                blackhole(5) refers to a route that, if matched,\n                discards the message silently.')
mplsL3VpnVrfRteInetCidrProto = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 9), IANAipRouteProtocol()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrProto.setDescription('The routing mechanism via which this route was learned.\n                Inclusion of values for gateway routing protocols is\n                not intended to imply that hosts should support those\n                protocols.')
mplsL3VpnVrfRteInetCidrAge = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 10), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrAge.setDescription("The number of seconds since this route was last updated\n                or otherwise determined to be correct.  Note that no\n                semantics of 'too old' can be implied except through\n                knowledge of the routing protocol by which the route\n                was learned.")
mplsL3VpnVrfRteInetCidrNextHopAS = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 11), InetAutonomousSystemNumber()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrNextHopAS.setDescription("The Autonomous System Number of the next hop.  The\n                semantics of this object are determined by the\n                routing protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto value.  When this\n                object is unknown or not relevant, its value should\n                be set to zero.")
mplsL3VpnVrfRteInetCidrMetric1 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),)).clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrMetric1.setDescription("The primary routing metric for this route.  The\n                semantics of this metric are determined by the\n                routing protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto value.  If this\n                metric is not used, its value should be set to\n                -1.")
mplsL3VpnVrfRteInetCidrMetric2 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),)).clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrMetric2.setDescription("An alternate routing metric for this route.  The\n                semantics of this metric are determined by the routing\n                protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto\n                value.  If this metric is not used, its value should be\n                set to -1.")
mplsL3VpnVrfRteInetCidrMetric3 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),)).clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrMetric3.setDescription("An alternate routing metric for this route.  The\n                semantics of this metric are determined by the routing\n                protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto\n                value.  If this metric is not used, its value should be\n                set to -1.")
mplsL3VpnVrfRteInetCidrMetric4 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),)).clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrMetric4.setDescription("An alternate routing metric for this route.  The\n                semantics of this metric are determined by the routing\n                protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto value.  If this metric\n                is not used, its value should be set to -1.")
mplsL3VpnVrfRteInetCidrMetric5 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),)).clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrMetric5.setDescription("An alternate routing metric for this route.  The\n                semantics of this metric are determined by the routing\n                protocol specified in the route's\n                mplsL3VpnVrfRteInetCidrProto value.  If this metric is\n                not used, its value should be set to -1.")
mplsL3VpnVrfRteXCPointer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 17), MplsIndexType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteXCPointer.setDescription('Index into mplsXCTable that identifies which cross-\n        connect entry is associated with this VRF route entry\n        by containing the mplsXCIndex of that cross-connect entry.\n        The string containing the single-octet 0x00 indicates that\n        a label stack is not associated with this route entry.  This\n        can be the case because the label bindings have not yet\n        been established, or because some change in the agent has\n        removed them.\n\n        When the label stack associated with this VRF route is created,\n        it MUST establish the associated cross-connect\n        entry in the mplsXCTable and then set that index to the value\n        of this object.  Changes to the cross-connect object in the\n        mplsXCTable MUST automatically be reflected in the value of\n        this object.  If this object represents a static routing entry,\n        then the manager must ensure that this entry is maintained\n        consistently in the corresponding mplsXCTable as well.')
mplsL3VpnVrfRteInetCidrStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 11, 1, 4, 1, 1, 18), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsL3VpnVrfRteInetCidrStatus.setDescription('The row status variable, used according to row\n                installation and removal conventions.\n                A row entry cannot be modified when the status is\n                marked as active(1).')
mplsL3VpnVrfUp = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 1)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfConfRowStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfOperStatus"),))
if mibBuilder.loadTexts: mplsL3VpnVrfUp.setDescription('This notification is generated when:\n        a. No interface is associated with this VRF, and the first\n           (and only first) interface associated with it has its\n           ifOperStatus change to up(1).\n\n        b. One interface is associated with this VRF, and\n           the ifOperStatus of this interface changes to up(1).\n\n        c. Multiple interfaces are associated with this VRF, and the\n           ifOperStatus of all interfaces is down(2), and the first\n           of those interfaces has its ifOperStatus change to up(1).')
mplsL3VpnVrfDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 2)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfConfRowStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfOperStatus"),))
if mibBuilder.loadTexts: mplsL3VpnVrfDown.setDescription('This notification is generated when:\n        a. One interface is associated with this VRF, and\n           the ifOperStatus of this interface changes from up(1)\n           to down(2).\n\n        b. Multiple interfaces are associated with this VRF, and\n           the ifOperStatus of all except one of these interfaces is\n           equal to up(1), and the ifOperStatus of that interface\n           changes from up(1) to down(2).\n\n        c. The last interface with ifOperStatus equal to up(1)\n           is disassociated from a VRF.')
mplsL3VpnVrfRouteMidThreshExceeded = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 3)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfCurrNumRoutes"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfMidRteThresh"),))
if mibBuilder.loadTexts: mplsL3VpnVrfRouteMidThreshExceeded.setDescription('This notification is generated when the number of routes\n        contained by the specified VRF exceeds the value indicated by\n        mplsL3VpnVrfMidRouteThreshold.  A single notification MUST be\n        generated when this threshold is exceeded, and no other\n        notifications of this type should be issued until the value\n        of mplsL3VpnVrfPerfCurrNumRoutes has fallen below that of\n        mplsL3VpnVrfConfMidRteThresh.')
mplsL3VpnVrfNumVrfRouteMaxThreshExceeded = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 4)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfCurrNumRoutes"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfHighRteThresh"),))
if mibBuilder.loadTexts: mplsL3VpnVrfNumVrfRouteMaxThreshExceeded.setDescription('This notification is generated when the number of routes\n        contained by the specified VRF exceeds or attempts to exceed\n        the maximum allowed value as indicated by\n        mplsL3VpnVrfMaxRouteThreshold.  In cases where\n        mplsL3VpnVrfConfHighRteThresh is set to the same value\n        as mplsL3VpnVrfConfMaxRoutes, mplsL3VpnVrfConfHighRteThresh\n        need not be exceeded; rather, just reached for this notification\n        to be issued.\n\n        Note that mplsL3VpnVrfConfRteMxThrshTime denotes the interval\n        at which the this notification will be reissued after the\n        maximum value has been exceeded (or reached if\n        mplsL3VpnVrfConfMaxRoutes and mplsL3VpnVrfConfHighRteThresh are\n        equal) and the initial notification has been issued.  This value\n        is intended to prevent continuous generation of notifications by\n        an agent in the event that routes are continually added to a VRF\n        after it has reached its maximum value.  The default value is 0\n        minutes.  If this value is set to 0, the agent should only issue\n        a single notification at the time that the maximum threshold has\n        been reached, and should not issue any more notifications until\n        the value of routes has fallen below the configured threshold\n        value.')
mplsL3VpnNumVrfSecIllglLblThrshExcd = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 5)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfSecIllegalLblVltns"),))
if mibBuilder.loadTexts: mplsL3VpnNumVrfSecIllglLblThrshExcd.setDescription('This notification is generated when the number of illegal\n        label violations on a VRF as indicated by\n        mplsL3VpnVrfSecIllegalLblVltns has exceeded\n        mplsL3VpnIllLblRcvThrsh.  The threshold is not\n        included in the varbind here because the value of\n        mplsL3VpnVrfSecIllegalLblVltns should be one greater than\n        the threshold at the time this notification is issued.')
mplsL3VpnNumVrfRouteMaxThreshCleared = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 11, 0, 6)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfCurrNumRoutes"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfHighRteThresh"),))
if mibBuilder.loadTexts: mplsL3VpnNumVrfRouteMaxThreshCleared.setDescription('This notification is generated only after the number of routes\n        contained by the specified VRF exceeds or attempts to exceed\n        the maximum allowed value as indicated by\n        mplsVrfMaxRouteThreshold, and then falls below this value.  The\n        emission of this notification informs the operator that the\n        error condition has been cleared without the operator having to\n        query the device.\n\n        Note that mplsL3VpnVrfConfRteMxThrshTime denotes the interval at\n        which the mplsNumVrfRouteMaxThreshExceeded notification will\n        be reissued after the maximum value has been exceeded (or\n        reached if mplsL3VpnVrfConfMaxRoutes and\n        mplsL3VpnVrfConfHighRteThresh are equal) and the initial\n        notification has been issued.  Therefore,\n        the generation of this notification should also be emitted with\n        this same frequency (assuming that the error condition is\n        cleared).  Specifically, if the error condition is reached and\n        cleared several times during the period of time specified in\n        mplsL3VpnVrfConfRteMxThrshTime, only a single notification will\n        be issued to indicate the first instance of the error condition\n        as well as the first time the error condition is cleared.\n        This behavior is intended to prevent continuous generation of\n        notifications by an agent in the event that routes are\n        continually added and removed to/from a VRF after it has\n        reached its maximum value.  The default value is 0.  If this\n        value is set to 0, the agent should issue a notification\n        whenever the maximum threshold has been cleared.')
mplsL3VpnGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1))
mplsL3VpnCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 2))
mplsL3VpnModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 2, 1)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnScalarGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnPerfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnSecGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnNotificationGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnPerfRouteGroup"),))
if mibBuilder.loadTexts: mplsL3VpnModuleFullCompliance.setDescription('Compliance statement for agents that provide full support\n           for the MPLS-L3VPN-STD-MIB')
mplsL3VpnModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 2, 2)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnScalarGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnPerfGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnSecGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnNotificationGroup"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnPerfRouteGroup"),))
if mibBuilder.loadTexts: mplsL3VpnModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only\n                   provide read-only support for MPLS-L3VPN-STD-MIB.\n                   Such devices can then be monitored but cannot be\n                   configured using this MIB module.')
mplsL3VpnScalarGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 1)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnConfiguredVrfs"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnActiveVrfs"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnConnectedInterfaces"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnNotificationEnable"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfMaxPossRts"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfRteMxThrshTime"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIllLblRcvThrsh"),))
if mibBuilder.loadTexts: mplsL3VpnScalarGroup.setDescription('Collection of scalar objects required for MPLS VPN\n              management.')
mplsL3VpnVrfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 2)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfVpnId"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfDescription"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRD"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfCreationTime"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfOperStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfActiveInterfaces"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfAssociatedInterfaces"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfMidRteThresh"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfHighRteThresh"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfMaxRoutes"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfLastChanged"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfRowStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfAdminStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfConfStorageType"),))
if mibBuilder.loadTexts: mplsL3VpnVrfGroup.setDescription('Collection of objects needed for MPLS VPN VRF\n              management.')
mplsL3VpnIfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 3)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfVpnClassification"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfVpnRouteDistProtocol"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfConfStorageType"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnIfConfRowStatus"),))
if mibBuilder.loadTexts: mplsL3VpnIfGroup.setDescription('Collection of objects needed for MPLS VPN interface\n              management.')
mplsL3VpnPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 4)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfRoutesAdded"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfRoutesDeleted"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfCurrNumRoutes"),))
if mibBuilder.loadTexts: mplsL3VpnPerfGroup.setDescription('Collection of objects needed for MPLS VPN\n              performance information.')
mplsL3VpnPerfRouteGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 5)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfRoutesDropped"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfPerfDiscTime"),))
if mibBuilder.loadTexts: mplsL3VpnPerfRouteGroup.setDescription('Collection of objects needed to track MPLS VPN\n              routing table dropped routes.')
mplsL3VpnSecGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 7)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfSecIllegalLblVltns"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfSecDiscontinuityTime"),))
if mibBuilder.loadTexts: mplsL3VpnSecGroup.setDescription('Collection of objects needed for MPLS VPN\n              security-related information.')
mplsL3VpnVrfRteGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 8)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrIfIndex"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrType"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrProto"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrAge"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrNextHopAS"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrMetric1"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrMetric2"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrMetric3"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrMetric4"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrMetric5"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteXCPointer"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRteInetCidrStatus"),))
if mibBuilder.loadTexts: mplsL3VpnVrfRteGroup.setDescription('Objects required for VRF route table management.')
mplsL3VpnVrfRTGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 9)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTDescr"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRT"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTRowStatus"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRTStorageType"),))
if mibBuilder.loadTexts: mplsL3VpnVrfRTGroup.setDescription('Objects required for VRF route target management.')
mplsL3VpnNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 166, 11, 2, 1, 10)).setObjects(*(("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfUp"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfDown"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfRouteMidThreshExceeded"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnVrfNumVrfRouteMaxThreshExceeded"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnNumVrfSecIllglLblThrshExcd"), ("MPLS-L3VPN-STD-MIB", "mplsL3VpnNumVrfRouteMaxThreshCleared"),))
if mibBuilder.loadTexts: mplsL3VpnNotificationGroup.setDescription('Objects required for MPLS VPN notifications.')
mibBuilder.exportSymbols("MPLS-L3VPN-STD-MIB", mplsL3VpnVrfDescription=mplsL3VpnVrfDescription, mplsL3VpnVrfRteInetCidrPolicy=mplsL3VpnVrfRteInetCidrPolicy, mplsL3VpnIfConfStorageType=mplsL3VpnIfConfStorageType, mplsL3VpnVrfRteXCPointer=mplsL3VpnVrfRteXCPointer, mplsL3VpnIfConfEntry=mplsL3VpnIfConfEntry, mplsL3VpnVrfSecTable=mplsL3VpnVrfSecTable, mplsL3VpnVrfActiveInterfaces=mplsL3VpnVrfActiveInterfaces, mplsL3VpnVrfSecIllegalLblVltns=mplsL3VpnVrfSecIllegalLblVltns, mplsL3VpnModuleFullCompliance=mplsL3VpnModuleFullCompliance, mplsL3VpnVrfPerfRoutesDropped=mplsL3VpnVrfPerfRoutesDropped, mplsL3VpnVrfRTEntry=mplsL3VpnVrfRTEntry, mplsL3VpnRoute=mplsL3VpnRoute, mplsL3VpnScalarGroup=mplsL3VpnScalarGroup, mplsL3VpnVrfName=mplsL3VpnVrfName, mplsL3VpnVrfConfRowStatus=mplsL3VpnVrfConfRowStatus, mplsL3VpnPerfRouteGroup=mplsL3VpnPerfRouteGroup, mplsL3VpnVrfTable=mplsL3VpnVrfTable, mplsL3VpnConf=mplsL3VpnConf, mplsL3VpnConnectedInterfaces=mplsL3VpnConnectedInterfaces, MplsL3VpnName=MplsL3VpnName, mplsL3VpnVrfRteInetCidrMetric1=mplsL3VpnVrfRteInetCidrMetric1, mplsL3VpnVrfAssociatedInterfaces=mplsL3VpnVrfAssociatedInterfaces, mplsL3VpnMIB=mplsL3VpnMIB, mplsL3VpnNumVrfRouteMaxThreshCleared=mplsL3VpnNumVrfRouteMaxThreshCleared, mplsL3VpnVrfGroup=mplsL3VpnVrfGroup, mplsL3VpnVrfRteGroup=mplsL3VpnVrfRteGroup, mplsL3VpnVrfRTIndex=mplsL3VpnVrfRTIndex, mplsL3VpnVrfRteInetCidrNextHopAS=mplsL3VpnVrfRteInetCidrNextHopAS, mplsL3VpnConformance=mplsL3VpnConformance, mplsL3VpnVrfConfHighRteThresh=mplsL3VpnVrfConfHighRteThresh, mplsL3VpnVrfConfMaxPossRts=mplsL3VpnVrfConfMaxPossRts, mplsL3VpnVrfRTType=mplsL3VpnVrfRTType, mplsL3VpnVrfRTTable=mplsL3VpnVrfRTTable, mplsL3VpnVrfRteInetCidrDest=mplsL3VpnVrfRteInetCidrDest, mplsL3VpnIfVpnClassification=mplsL3VpnIfVpnClassification, mplsL3VpnVrfEntry=mplsL3VpnVrfEntry, mplsL3VpnIfConfTable=mplsL3VpnIfConfTable, mplsL3VpnCompliances=mplsL3VpnCompliances, mplsL3VpnVrfRTGroup=mplsL3VpnVrfRTGroup, mplsL3VpnNotifications=mplsL3VpnNotifications, mplsL3VpnActiveVrfs=mplsL3VpnActiveVrfs, mplsL3VpnVrfPerfDiscTime=mplsL3VpnVrfPerfDiscTime, mplsL3VpnIfVpnRouteDistProtocol=mplsL3VpnIfVpnRouteDistProtocol, mplsL3VpnVrfConfMaxRoutes=mplsL3VpnVrfConfMaxRoutes, mplsL3VpnVrfPerfCurrNumRoutes=mplsL3VpnVrfPerfCurrNumRoutes, mplsL3VpnVrfSecEntry=mplsL3VpnVrfSecEntry, mplsL3VpnVrfVpnId=mplsL3VpnVrfVpnId, mplsL3VpnVrfRouteMidThreshExceeded=mplsL3VpnVrfRouteMidThreshExceeded, mplsL3VpnVrfDown=mplsL3VpnVrfDown, mplsL3VpnVrfRTDescr=mplsL3VpnVrfRTDescr, mplsL3VpnVrfConfRteMxThrshTime=mplsL3VpnVrfConfRteMxThrshTime, mplsL3VpnVrfRT=mplsL3VpnVrfRT, mplsL3VpnVrfRteInetCidrStatus=mplsL3VpnVrfRteInetCidrStatus, mplsL3VpnVrfRteInetCidrAge=mplsL3VpnVrfRteInetCidrAge, mplsL3VpnIllLblRcvThrsh=mplsL3VpnIllLblRcvThrsh, mplsL3VpnVrfSecDiscontinuityTime=mplsL3VpnVrfSecDiscontinuityTime, mplsL3VpnVrfRD=mplsL3VpnVrfRD, mplsL3VpnVrfRteInetCidrIfIndex=mplsL3VpnVrfRteInetCidrIfIndex, mplsL3VpnVrfRteInetCidrMetric3=mplsL3VpnVrfRteInetCidrMetric3, mplsL3VpnSecGroup=mplsL3VpnSecGroup, mplsL3VpnVrfOperStatus=mplsL3VpnVrfOperStatus, mplsL3VpnVrfRteInetCidrNHopType=mplsL3VpnVrfRteInetCidrNHopType, mplsL3VpnConfiguredVrfs=mplsL3VpnConfiguredVrfs, mplsL3VpnVrfRteInetCidrDestType=mplsL3VpnVrfRteInetCidrDestType, mplsL3VpnVrfConfAdminStatus=mplsL3VpnVrfConfAdminStatus, mplsL3VpnNotificationGroup=mplsL3VpnNotificationGroup, mplsL3VpnVrfRteInetCidrPfxLen=mplsL3VpnVrfRteInetCidrPfxLen, mplsL3VpnVrfRteInetCidrMetric2=mplsL3VpnVrfRteInetCidrMetric2, mplsL3VpnScalars=mplsL3VpnScalars, mplsL3VpnModuleReadOnlyCompliance=mplsL3VpnModuleReadOnlyCompliance, mplsL3VpnVrfNumVrfRouteMaxThreshExceeded=mplsL3VpnVrfNumVrfRouteMaxThreshExceeded, mplsL3VpnVrfRteInetCidrMetric5=mplsL3VpnVrfRteInetCidrMetric5, mplsL3VpnVrfRteInetCidrType=mplsL3VpnVrfRteInetCidrType, mplsL3VpnVrfRteEntry=mplsL3VpnVrfRteEntry, PYSNMP_MODULE_ID=mplsL3VpnMIB, mplsL3VpnVrfCreationTime=mplsL3VpnVrfCreationTime, mplsL3VpnPerf=mplsL3VpnPerf, MplsL3VpnRtType=MplsL3VpnRtType, mplsL3VpnVrfRTStorageType=mplsL3VpnVrfRTStorageType, mplsL3VpnVrfRteInetCidrNextHop=mplsL3VpnVrfRteInetCidrNextHop, mplsL3VpnVrfUp=mplsL3VpnVrfUp, mplsL3VpnObjects=mplsL3VpnObjects, mplsL3VpnVrfPerfRoutesDeleted=mplsL3VpnVrfPerfRoutesDeleted, mplsL3VpnVrfConfLastChanged=mplsL3VpnVrfConfLastChanged, mplsL3VpnVrfPerfEntry=mplsL3VpnVrfPerfEntry, mplsL3VpnNumVrfSecIllglLblThrshExcd=mplsL3VpnNumVrfSecIllglLblThrshExcd, mplsL3VpnPerfGroup=mplsL3VpnPerfGroup, mplsL3VpnVrfRteTable=mplsL3VpnVrfRteTable, mplsL3VpnIfConfIndex=mplsL3VpnIfConfIndex, mplsL3VpnIfGroup=mplsL3VpnIfGroup, MplsL3VpnRouteDistinguisher=MplsL3VpnRouteDistinguisher, mplsL3VpnGroups=mplsL3VpnGroups, mplsL3VpnIfConfRowStatus=mplsL3VpnIfConfRowStatus, mplsL3VpnVrfPerfTable=mplsL3VpnVrfPerfTable, mplsL3VpnVrfRteInetCidrMetric4=mplsL3VpnVrfRteInetCidrMetric4, mplsL3VpnVrfPerfRoutesAdded=mplsL3VpnVrfPerfRoutesAdded, mplsL3VpnVrfConfMidRteThresh=mplsL3VpnVrfConfMidRteThresh, mplsL3VpnVrfRTRowStatus=mplsL3VpnVrfRTRowStatus, mplsL3VpnVrfRteInetCidrProto=mplsL3VpnVrfRteInetCidrProto, mplsL3VpnNotificationEnable=mplsL3VpnNotificationEnable, mplsL3VpnVrfConfStorageType=mplsL3VpnVrfConfStorageType)
